@@ -1,6 +1,7 @@
 from __future__ import annotations
 from pathlib import Path
-from typing import List, Optional, TYPE_CHECKING
+from typing import List, Optional, Tuple, TYPE_CHECKING
+from . import util
 
 
 if TYPE_CHECKING:
@@ -11,28 +12,23 @@ if TYPE_CHECKING:
 class Task:
     """
     Task to be executed.
-
-    Args:
-        name: Name of the task.
-        dependencies: Files that the task depends on.
-        targets: Files that the task will generate.
-        action: Action to execute when the task is run.
-        task_dependencies: Tasks that should be executed prior to this task.
     """
     def __init__(
             self,
             name: str,
             *,
-            dependencies: Optional[List[PathOrStr]] = None,
-            targets: Optional[List[PathOrStr]] = None,
+            dependencies: Optional[List["PathOrStr"]] = None,
+            targets: Optional[List["PathOrStr"]] = None,
             action: Optional[Action] = None,
             task_dependencies: Optional[List[Task]] = None,
+            location: Optional[Tuple[str, int]] = None,
             ) -> None:
         self.name = name
         self.dependencies = dependencies or []
         self.targets = [Path(path) for path in (targets or [])]
         self.action = action
         self.task_dependencies = task_dependencies or []
+        self.location = location or util.get_location()
 
     async def execute(self) -> None:
         if self.action:
@@ -42,4 +38,5 @@ class Task:
         return hash(self.name)
 
     def __repr__(self) -> str:
-        return f"{self.name}({len(self.dependencies)} -> {len(self.targets)})"
+        filename, lineno = self.location
+        return f"<task `{self.name}` @ {filename}:{lineno}>"
